==> jc-1.4.0.tar.gz: java/sql/DataTruncation.h <==
// public class java.sql.DataTruncation

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b35868f9aa437ff5 java_sql_DataTruncation
// @dep_class d5428f1f1b6fb1d3 java_sql_SQLException
// @dep_class 3ee7c8583e39880d java_sql_SQLWarning

// header file dependencies
// @dep_header java_sql_SQLWarning

#include "java/sql/SQLWarning.h"

#ifndef _JC_java_sql_DataTruncation_H_
#define _JC_java_sql_DataTruncation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_sql_DataTruncation$sub_refs	_jc_java_sql_DataTruncation$sub_refs;
typedef struct _jc_java_sql_DataTruncation$sub_nonrefs	_jc_java_sql_DataTruncation$sub_nonrefs;
typedef struct _jc_java_sql_DataTruncation$refs	_jc_java_sql_DataTruncation$refs;
typedef struct _jc_java_sql_DataTruncation$nonrefs	_jc_java_sql_DataTruncation$nonrefs;
typedef struct _jc_java_sql_DataTruncation$object	_jc_java_sql_DataTruncation$object;

typedef struct _jc_java_sql_DataTruncation$fields_struct	_jc_java_sql_DataTruncation$fields_struct;
typedef const struct _jc_java_sql_DataTruncation$vmethods	_jc_java_sql_DataTruncation$vmethods;
typedef const struct _jc_java_sql_DataTruncation$vtable	_jc_java_sql_DataTruncation$vtable;
typedef const struct _jc_java_sql_DataTruncation$vtype	_jc_java_sql_DataTruncation$vtype;

// Class fields structure
struct _jc_java_sql_DataTruncation$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_sql_DataTruncation$fields_struct _jc_java_sql_DataTruncation$class_fields;

// Constructors
extern void _jc_java_sql_DataTruncation$method$_init$dd76a674ccee9d7b(_jc_env *, struct _jc_java_sql_DataTruncation$object *, jint, jboolean, jboolean, jint, jint);

// Virtual methods
extern jint _jc_java_sql_DataTruncation$method$getDataSize$4951bb294d1fa41e(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
extern jint _jc_java_sql_DataTruncation$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
extern jboolean _jc_java_sql_DataTruncation$method$getParameter$4f0093c5560a0734(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
extern jboolean _jc_java_sql_DataTruncation$method$getRead$2aaef3ce195beadb(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
extern jint _jc_java_sql_DataTruncation$method$getTransferSize$852929f2762eda42(_jc_env *, struct _jc_java_sql_DataTruncation$object *);

// Virtual method descriptors
extern _jc_method _jc_java_sql_DataTruncation$method_info$getDataSize$4951bb294d1fa41e;
extern _jc_method _jc_java_sql_DataTruncation$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_java_sql_DataTruncation$method_info$getParameter$4f0093c5560a0734;
extern _jc_method _jc_java_sql_DataTruncation$method_info$getRead$2aaef3ce195beadb;
extern _jc_method _jc_java_sql_DataTruncation$method_info$getTransferSize$852929f2762eda42;

// Virtual methods structure
struct _jc_java_sql_DataTruncation$vmethods {
	jint	(*getDataSize$4951bb294d1fa41e)(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
	jboolean	(*getParameter$4f0093c5560a0734)(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
	jboolean	(*getRead$2aaef3ce195beadb)(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
	jint	(*getTransferSize$852929f2762eda42)(_jc_env *, struct _jc_java_sql_DataTruncation$object *);
};

// Vtable
struct _jc_java_sql_DataTruncation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_sql_SQLException$vmethods	java_sql_SQLException;
	_jc_java_sql_SQLWarning$vmethods	java_sql_SQLWarning;
	_jc_java_sql_DataTruncation$vmethods	java_sql_DataTruncation;
};

// Vtype
struct _jc_java_sql_DataTruncation$vtype {
	_jc_type			type;
	_jc_java_sql_DataTruncation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_DataTruncation$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_DataTruncation$refs {
    _jc_java_sql_DataTruncation$sub_refs	java_sql_DataTruncation;
    _jc_java_sql_SQLWarning$sub_refs	java_sql_SQLWarning;
    _jc_java_sql_SQLException$sub_refs	java_sql_SQLException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_DataTruncation$sub_nonrefs {
	jint	dataSize;
	jint	index;
	jboolean	parameter;
	jboolean	read;
	jint	transferSize;
};

// Non-reference instance fields (object)
struct _jc_java_sql_DataTruncation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_sql_SQLException$sub_nonrefs	java_sql_SQLException;
    _jc_java_sql_SQLWarning$sub_nonrefs	java_sql_SQLWarning;
    _jc_java_sql_DataTruncation$sub_nonrefs	java_sql_DataTruncation;
};

// Object instance structure
struct _jc_java_sql_DataTruncation$object {
	_jc_java_sql_DataTruncation$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_DataTruncation$vtype	*vtype;
	_jc_java_sql_DataTruncation$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_DataTruncation$vtype _jc_java_sql_DataTruncation$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_DataTruncation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_DataTruncation$class_object;

#endif	/* _JC_java_sql_DataTruncation_H_ */

==> jc-1.4.6.tar.gz: java/sql/DataTruncation.h <==
// public class java.sql.DataTruncation

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class b35868f9aa437ff5 java_sql_DataTruncation
// @dep_class d5428f1f1b6fb1d3 java_sql_SQLException
// @dep_class 3ee7c8583e39880d java_sql_SQLWarning

// header file dependencies
// @dep_header java_sql_SQLWarning

#include "java/sql/SQLWarning.h"

#ifndef _JC_java_sql_DataTruncation_H_
#define _JC_java_sql_DataTruncation_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_sql_DataTruncation$sub_refs	_jc_java_sql_DataTruncation$sub_refs;
typedef struct _jc_java_sql_DataTruncation$sub_nonrefs	_jc_java_sql_DataTruncation$sub_nonrefs;
typedef struct _jc_java_sql_DataTruncation$refs	_jc_java_sql_DataTruncation$refs;
typedef struct _jc_java_sql_DataTruncation$nonrefs	_jc_java_sql_DataTruncation$nonrefs;
typedef struct _jc_java_sql_DataTruncation$object	_jc_java_sql_DataTruncation$object;

typedef struct _jc_java_sql_DataTruncation$fields_struct	_jc_java_sql_DataTruncation$fields_struct;
typedef const struct _jc_java_sql_DataTruncation$vmethods	_jc_java_sql_DataTruncation$vmethods;
typedef const struct _jc_java_sql_DataTruncation$vtable	_jc_java_sql_DataTruncation$vtable;
typedef const struct _jc_java_sql_DataTruncation$vtype	_jc_java_sql_DataTruncation$vtype;

// Class fields structure
struct _jc_java_sql_DataTruncation$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_sql_DataTruncation$fields_struct _jc_java_sql_DataTruncation$class_fields;

// Constructors
extern void _jc_java_sql_DataTruncation$method$_init$dd76a674ccee9d7b(_jc_env *, struct _jc_java_sql_DataTruncation$object *, jint, jboolean, jboolean, jint, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_sql_DataTruncation$method$getDataSize$4951bb294d1fa41e(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
extern jint _jc_java_sql_DataTruncation$method$getIndex$71a8f9126346f049(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_sql_DataTruncation$method$getParameter$4f0093c5560a0734(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_sql_DataTruncation$method$getRead$2aaef3ce195beadb(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
extern jint _jc_java_sql_DataTruncation$method$getTransferSize$852929f2762eda42(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_sql_DataTruncation$method_info$getDataSize$4951bb294d1fa41e;
extern _jc_method _jc_java_sql_DataTruncation$method_info$getIndex$71a8f9126346f049;
extern _jc_method _jc_java_sql_DataTruncation$method_info$getParameter$4f0093c5560a0734;
extern _jc_method _jc_java_sql_DataTruncation$method_info$getRead$2aaef3ce195beadb;
extern _jc_method _jc_java_sql_DataTruncation$method_info$getTransferSize$852929f2762eda42;

// Virtual methods structure
struct _jc_java_sql_DataTruncation$vmethods {
	jint	(*getDataSize$4951bb294d1fa41e)(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
	jint	(*getIndex$71a8f9126346f049)(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
	jboolean	(*getParameter$4f0093c5560a0734)(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
	jboolean	(*getRead$2aaef3ce195beadb)(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
	jint	(*getTransferSize$852929f2762eda42)(_jc_env *, struct _jc_java_sql_DataTruncation$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_sql_DataTruncation$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_sql_SQLException$vmethods	java_sql_SQLException;
	_jc_java_sql_SQLWarning$vmethods	java_sql_SQLWarning;
	_jc_java_sql_DataTruncation$vmethods	java_sql_DataTruncation;
};

// Vtype
struct _jc_java_sql_DataTruncation$vtype {
	_jc_type			type;
	_jc_java_sql_DataTruncation$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_sql_DataTruncation$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_sql_DataTruncation$refs {
    _jc_java_sql_DataTruncation$sub_refs	java_sql_DataTruncation;
    _jc_java_sql_SQLWarning$sub_refs	java_sql_SQLWarning;
    _jc_java_sql_SQLException$sub_refs	java_sql_SQLException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_sql_DataTruncation$sub_nonrefs {
	jint	dataSize;
	jint	index;
	jboolean	parameter;
	jboolean	read;
	jint	transferSize;
};

// Non-reference instance fields (object)
struct _jc_java_sql_DataTruncation$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_sql_SQLException$sub_nonrefs	java_sql_SQLException;
    _jc_java_sql_SQLWarning$sub_nonrefs	java_sql_SQLWarning;
    _jc_java_sql_DataTruncation$sub_nonrefs	java_sql_DataTruncation;
};

// Object instance structure
struct _jc_java_sql_DataTruncation$object {
	_jc_java_sql_DataTruncation$refs	refs[0];
	_jc_word		lockword;
	_jc_java_sql_DataTruncation$vtype	*vtype;
	_jc_java_sql_DataTruncation$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_sql_DataTruncation$vtype _jc_java_sql_DataTruncation$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_sql_DataTruncation, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_sql_DataTruncation$class_object;

#endif	/* _JC_java_sql_DataTruncation_H_ */
